@@ -42,6 +42,9 @@ class Uuid(metaclass=abc.ABCMeta):
         return self.__value
 
     def __eq__(self, other: Uuid) -> bool:
+        if not other:
+            return False
+
         return self.value == other.value
 
     def __str__(self) -> str:
